#!/bin/bash
#   author:martinmhan@yahoo.com date:  22/04/2014
#   scadat is a bash command line interface to the tango scada (and in future epics)
#   Copyright (C) <2014>  <Martin Mohan>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software Foundation,
#   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

#set -x
verbose=0
if [ x$1 = x"" ]; then 
    export verbose=0
else
    export verbose=1
fi

export PATH=.:$PATH
source scadat_unittest.sh
echo "Call: `which scadat`"

if [ -z "$TANGO_HOST" ]; then
    export TANGO_HOST="scadat.org:10000"
    echo "TANGO_HOST not set: export TANGO_HOST=scadat.org:10000"
fi  

assertEquals "scadat $TANGO_HOST -v" "tango_open:TANGO_HOST=$TANGO_HOST";
if [ ! $? -eq 0 ]; then
    echo "Failed to open TANGO_HOST=$TANGO_HOST - Try 'export TANGO_HOST=scadat.org:10000'"
    exit 1
fi

assertEquals "scadat" "scadat -h: For usage"
assertContains "scadat -i" "scadat_version"
assertContains "scadat -l" "sys/tg_test/1"
assertEquals "scadat scadat.org:12345" "tango_closed:TANGO_HOST=scadat.org:12345"
assertContains "scadat Unknown" "set TANGO_HOST e.g. export TANGO_HOST=scadat.org:10000"
assertContains "scadat -r aa/bb/cc" "Cannot Open device aa/bb/cc on"
assertEquals "scadat -c sys/tg_test/1/Init" "None"
assertEquals "scadat -r sys/tg_test/1 | grep Status" "sys/tg_test/1/Status <attr_ro>"
assertContains "scadat -c sys/tg_test/1/DevFloat 12.34" "12.34"

assertContains "scadat -c sys/tg_test/1" "Usage: scadat -c sys/tg_test/1 <cmd_name> value"
assertContains "scadat -c sys/tg_test/1/Status" "The device is"

assertEquals "scadat -c sys/tg_test/1/DevDouble 12.34" "12.34"
assertEquals "scadat -c sys/tg_test/1/DevLong 1234" "1234"
assertEquals "scadat -c sys/tg_test/1/DevLong64 1234" "1234"
assertEquals "scadat -c sys/tg_test/1/DevULong64 1234" "1234"
assertEquals "scadat -c sys/tg_test/1/DevULong 1234" "1234"
assertEquals "scadat -c sys/tg_test/1/DevBoolean 0" "False"
assertEquals "scadat -c sys/tg_test/1/DevBoolean 1" "True"
assertEquals "scadat -c sys/tg_test/1/DevShort 1234" "1234"
assertEquals "scadat -c sys/tg_test/1/DevUShort 1234" "1234"
assertEquals "scadat -c sys/tg_test/1/DevString 'my string'" "my string"
assertEquals "scadat -c sys/tg_test/1/DevVarLongArray '1 2 3 4'" "[1 2 3 4]"
assertEquals "scadat -c sys/tg_test/1/DevVarLong64Array '1 2 3 4'" "[1 2 3 4]"
assertEquals "scadat -c sys/tg_test/1/DevVarULong64Array '1 2 3 4'" "[1 2 3 4]"
assertContains "scadat -c sys/tg_test/1/DevVarFloatArray '1.123456 2.2 3.3 4.4'" "1.123456"
assertContains "scadat -c sys/tg_test/1/DevVarDoubleArray '1.123456 2.2 3.3 4.4'" "1.123456"
assertEquals "scadat -c sys/tg_test/1/DevVarUShortArray '1 2 3 4'" "[1 2 3 4]"
assertEquals "scadat -c sys/tg_test/1/DevVarShortArray '1 2 3 4'" "[1 2 3 4]"
assertEquals "scadat -c sys/tg_test/1/DevVarStringArray 'string1 string2 string3 string4'" "['string1', 'string2', 'string3', 'string4']"
assertEquals "scadat -c sys/tg_test/1/DevVoid None" "None"

# attribute_read_all
assertEquals "scadat -r sys/tg_test/1 | grep long_scalar_rww" "sys/tg_test/1/long_scalar_rww <attr_w>"
assertEquals "scadat -r sys/tg_test/1 | grep ulong_image_ro" "sys/tg_test/1/ulong_image_ro <attr_ro>"
# attribute_read_single
assertContains "scadat -r sys/tg_test/1 | grep 'short_scalar_rww'" "sys/tg_test/1/short_scalar_rww"
# Read 1 command
assertEquals "scadat -r sys/tg_test/1 | grep ushort_scalar" "sys/tg_test/1/ushort_scalar <attr_w>"
assertEquals "scadat -r sys/tg_test/1 | grep long_scalar_w" "sys/tg_test/1/long_scalar_w <attr_w>"
# Write/Read Attributes
assertContains "scadat -w sys/tg_test/1" "Usage: scadat -w sys/tg_test/1 <attr_name_w> value"
assertEquals "scadat -w sys/tg_test/1/long_scalar_w" "Usage: scadat -w sys/tg_test/1  long_scalar_w <DevLong>"
assertEquals "scadat -w sys/tg_test/1/long_scalar_w 4321" "sys/tg_test/1/long_scalar_w->4321"
assertEquals "scadat -r sys/tg_test/1/long_scalar_w" "4321"
#assertTrue "scadat -r sys/tg_test/1/long_scalar_w | grep '[0-9]\+'"
assertEquals "scadat -w sys/tg_test/1/long_scalar_w 1234" "sys/tg_test/1/long_scalar_w->1234"
assertEquals "scadat -r sys/tg_test/1/long_scalar_w" "1234"
assertEquals "scadat -w sys/tg_test/1/string_scalar 'my string 123'" "sys/tg_test/1/string_scalar->my string 123"
assertEquals "scadat -r sys/tg_test/1/string_scalar" "my string 123"
assertContains "scadat -r sys/tg_test/1/string_scalar -v" "sys/tg_test/1/string_scalar my string 123"

#assertEquals "scadat scadat.org:10000 -v" "tango_open:TANGO_HOST=scadat.org:10000"
#result=$?
##echo "result is $result"
#if [ "$result" != "0" ]; then
#    echo "Check network: nc -vz -w1 scadat.org 10000 - Network access- failed"
#else
#    echo "Check network: nc -vz -w1 scadat.org 10000 - Network access- ok"
#fi

#assertEquals "scadat -r sys/tg_test/1 | grep short_scalar_w" "sys/tg_test/1/short_scalar_w 4321"
#assertEquals "scadat -w sys/tg_test/1 short_scalar_w 4321" "short_scalar_w->4321"
#### Not supported - yet
#assertContains "$scadat -w sys/tg_test/1 DevVarDoubleStringArray '1 2 3 4'" "1 2 3 4"
#assertContains "$scadat -w sys/tg_test/1 DevVarCharArray '1 2 3 4'" "1 2 3 4"
#assertContains "$scadat -w sys/tg_test/1 DevVarLongStringArray 1234" "1234"
#echo "epics tests:"
#export SCADAT_HOST="EPICS"
#assertContains "$scadat -r 'CO_TEST:CLOCK1:SEC1' -v" "CO_TEST:CLOCK1:SEC1"
